@@ -1,6 +1,8 @@
 var passport=require('passport');
 var FacebookStrategy=require('passport-facebook').Strategy;
-module.exports=function(config){    
+const config=require(process.cwd()+'/config/config');
+
+module.exports=function(){    
      passport.use(new FacebookStrategy(
         {
             clientID:config.oauth.facebook.clientId,
